summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 20:02:44 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 21:01:29 +0200
commit45971e65a6114fbd1f91ae354da485450001166f (patch)
treeb607ce9f3b683a89478b8c21c6bc9a53bf6b7a44 /kopete/libkopete
parentc26bb519a8aebc04ffe39d0b6c784a1c1e915202 (diff)
downloadtdenetwork-45971e65a6114fbd1f91ae354da485450001166f.tar.gz
tdenetwork-45971e65a6114fbd1f91ae354da485450001166f.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'kopete/libkopete')
-rw-r--r--kopete/libkopete/CMakeLists.txt4
-rw-r--r--kopete/libkopete/Makefile.am8
-rw-r--r--kopete/libkopete/avdevice/Makefile.am2
-rw-r--r--kopete/libkopete/kopeteaccount.cpp2
-rw-r--r--kopete/libkopete/kopetecontact.cpp4
-rw-r--r--kopete/libkopete/kopetecontactlist.cpp2
-rw-r--r--kopete/libkopete/kopeteglobal.h6
-rw-r--r--kopete/libkopete/kopetemetacontact.cpp32
-rw-r--r--kopete/libkopete/kopetemetacontact.h4
-rw-r--r--kopete/libkopete/kopeteprotocol.cpp12
-rw-r--r--kopete/libkopete/kopetetransfermanager.h2
-rw-r--r--kopete/libkopete/tdeabcpersistence.cpp (renamed from kopete/libkopete/kabcpersistence.cpp)6
-rw-r--r--kopete/libkopete/tdeabcpersistence.h (renamed from kopete/libkopete/kabcpersistence.h)2
-rw-r--r--kopete/libkopete/tests/kopetecontactlist_test.cpp4
-rw-r--r--kopete/libkopete/tests/kopeteemoticontest.cpp4
-rw-r--r--kopete/libkopete/tests/kopetemessage_test.cpp4
-rw-r--r--kopete/libkopete/tests/kopetepropertiestest.cpp4
-rw-r--r--kopete/libkopete/tests/template_test.cpp4
-rw-r--r--kopete/libkopete/ui/addressbookselectorwidget.cpp2
-rw-r--r--kopete/libkopete/ui/addresseeitem.h2
20 files changed, 55 insertions, 55 deletions
diff --git a/kopete/libkopete/CMakeLists.txt b/kopete/libkopete/CMakeLists.txt
index 113289cb..7c1130ea 100644
--- a/kopete/libkopete/CMakeLists.txt
+++ b/kopete/libkopete/CMakeLists.txt
@@ -46,7 +46,7 @@ install( FILES
kopetemimetypehandler.h kopeteonlinestatus.h kopeteonlinestatusmanager.h
kopetepasswordedaccount.h kopetepassword.h kopeteplugin.h
kopeteprotocol.h kopetesimplemessagehandler.h kopetetask.h
- kopetetransfermanager.h kopeteuiglobal.h kabcpersistence.h
+ kopetetransfermanager.h kopeteuiglobal.h tdeabcpersistence.h
managedconnectionaccount.h kopetenotifydataobject.h
kopeteversion.h kopeteprefs.h kopetepicture.h webcamwidget.h
kopetepluginmanager.h kopeteblacklister.h
@@ -80,7 +80,7 @@ tde_add_library( kopete SHARED AUTOMOC
kopetetask.cpp kopetemimesourcefactory.cpp kopeteeventpresentation.cpp
kopetenotifyevent.cpp kopetenotifydataobject.cpp kopeteblacklister.cpp
kopetemessageevent.cpp kopetemessagehandler.cpp kopetemessagehandlerchain.cpp
- kopetesimplemessagehandler.cpp kopeteproperties.cpp kabcpersistence.cpp
+ kopetesimplemessagehandler.cpp kopeteproperties.cpp tdeabcpersistence.cpp
connectionmanager.skel clientiface.stub managedconnectionaccount.cpp
networkstatuscommon.h kopeteconfig.kcfgc kopeteutils.cpp
kopeteprefs.cpp kopetepicture.cpp webcamwidget.cpp
diff --git a/kopete/libkopete/Makefile.am b/kopete/libkopete/Makefile.am
index 07d661f8..56fd99bb 100644
--- a/kopete/libkopete/Makefile.am
+++ b/kopete/libkopete/Makefile.am
@@ -30,19 +30,19 @@ libkopete_la_SOURCES = knotification.cpp connectionmanager.cpp kopeteonlinestatu
kopetemimetypehandler.cpp kopetetask.cpp kopetemimesourcefactory.cpp \
kopeteeventpresentation.cpp kopetenotifyevent.cpp kopetenotifydataobject.cpp kopeteblacklister.cpp \
kopetemessageevent.cpp kopetemessagehandler.cpp kopetemessagehandlerchain.cpp \
- kopetesimplemessagehandler.cpp kopeteproperties.cpp kabcpersistence.cpp connectionmanager.skel \
+ kopetesimplemessagehandler.cpp kopeteproperties.cpp tdeabcpersistence.cpp connectionmanager.skel \
clientiface.stub managedconnectionaccount.cpp networkstatuscommon.h kopeteconfig.kcfgc kopeteutils.cpp \
kopeteprefs.cpp kopetepicture.cpp webcamwidget.cpp
libkopete_la_LDFLAGS = -no-undefined -version-info 1:0:0 $(all_libraries)
-libkopete_la_LIBADD = -ltdeabc ui/libkopeteui.la $(COMPAT_LIBS) $(LIB_KIO) $(LIB_XSS) $(LIB_XRENDER)
+libkopete_la_LIBADD = -ltdeabc ui/libkopeteui.la $(COMPAT_LIBS) $(LIB_TDEIO) $(LIB_XSS) $(LIB_XRENDER)
kde_kcfg_DATA = kopete.kcfg
#AM_CXXFLAGS = -DQT_PLUGIN
#kde_widget_LTLIBRARIES = libkopetewidgets.la
#libkopetewidgets_la_LDFLAGS = $(KDE_PLUGIN) -module $(all_libraries)
-#libkopetewidgets_la_LIBADD = $(LIB_KIO) libkopete.la ui/libkopeteui.la
+#libkopetewidgets_la_LIBADD = $(LIB_TDEIO) libkopete.la ui/libkopeteui.la
#libkopetewidgets_la_SOURCES = ui/kopetewidgets.cpp
kopetewidgets.cpp: $(srcdir)/kopete.widgets
@@ -62,7 +62,7 @@ kopeteinclude_HEADERS = kopeteaccount.h kopeteaccountmanager.h kopeteawayaction.
kopetechatsession.h kopetechatsessionmanager.h kopetemetacontact.h kopetemimetypehandler.h \
kopeteonlinestatus.h kopeteonlinestatusmanager.h kopetepasswordedaccount.h \
kopetepassword.h kopeteplugin.h kopeteprotocol.h kopetesimplemessagehandler.h kopetetask.h \
- kopetetransfermanager.h kopeteuiglobal.h kabcpersistence.h managedconnectionaccount.h \
+ kopetetransfermanager.h kopeteuiglobal.h tdeabcpersistence.h managedconnectionaccount.h \
kopetenotifydataobject.h kopeteversion.h kopeteprefs.h kopetepicture.h webcamwidget.h \
kopetepluginmanager.h
diff --git a/kopete/libkopete/avdevice/Makefile.am b/kopete/libkopete/avdevice/Makefile.am
index 474d6a67..9036b3f2 100644
--- a/kopete/libkopete/avdevice/Makefile.am
+++ b/kopete/libkopete/avdevice/Makefile.am
@@ -5,7 +5,7 @@ AM_CPPFLAGS = -DKDE_NO_COMPAT -DQT_NO_COMPAT -DQT_NO_CAST_ASCII -DQT_NO_ASCII_CA
METASOURCES = AUTO
lib_LTLIBRARIES = libkopete_videodevice.la
noinst_LTLIBRARIES = libkvideoio.la
-libkopete_videodevice_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+libkopete_videodevice_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
noinst_HEADERS = kxv.h qvideo.h qvideostream.h videocontrol.h videodevice.h \
videodevicemodelpool.h videodevicepool.h videoinput.h \
diff --git a/kopete/libkopete/kopeteaccount.cpp b/kopete/libkopete/kopeteaccount.cpp
index 623fd2fd..4ea6909c 100644
--- a/kopete/libkopete/kopeteaccount.cpp
+++ b/kopete/libkopete/kopeteaccount.cpp
@@ -31,7 +31,7 @@
#include <tdemessagebox.h>
#include <knotifyclient.h>
-#include "kabcpersistence.h"
+#include "tdeabcpersistence.h"
#include "kopetecontactlist.h"
#include "kopeteaccount.h"
#include "kopeteaccountmanager.h"
diff --git a/kopete/libkopete/kopetecontact.cpp b/kopete/libkopete/kopetecontact.cpp
index 322a46f3..b1d9005e 100644
--- a/kopete/libkopete/kopetecontact.cpp
+++ b/kopete/libkopete/kopetecontact.cpp
@@ -26,7 +26,7 @@
#include <tdeversion.h>
#include <kinputdialog.h>
-#include <kabcpersistence.h>
+#include <tdeabcpersistence.h>
#include <kdialogbase.h>
#include <tdelocale.h>
#include <tdepopupmenu.h>
@@ -343,7 +343,7 @@ void Contact::setMetaContact( MetaContact *m )
m->addContact( this );
m->insertChild( this );
// it is necessary to call this write here, because MetaContact::addContact() does not differentiate
- // between adding completely new contacts (which should be written to kabc) and restoring upon restart
+ // between adding completely new contacts (which should be written to tdeabc) and restoring upon restart
// (where no write is needed).
KABCPersistence::self()->write( m );
connect( d->metaContact, TQT_SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
diff --git a/kopete/libkopete/kopetecontactlist.cpp b/kopete/libkopete/kopetecontactlist.cpp
index 394527d6..2a8d69c6 100644
--- a/kopete/libkopete/kopetecontactlist.cpp
+++ b/kopete/libkopete/kopetecontactlist.cpp
@@ -1097,7 +1097,7 @@ void ContactList::slotSaveLater()
void ContactList::slotKABCChanged()
{
// TODO: react to changes in KABC, replacing this function, post 3.4 (Will)
- // call syncWithKABC on each metacontact to check if its associated kabc entry has changed.
+ // call syncWithKABC on each metacontact to check if its associated tdeabc entry has changed.
/* for ( MetaContact * mc = d->contacts.first(); mc; mc = d->contacts.next() )
mc->syncWithKABC();*/
diff --git a/kopete/libkopete/kopeteglobal.h b/kopete/libkopete/kopeteglobal.h
index 7ecc6f5b..926e2645 100644
--- a/kopete/libkopete/kopeteglobal.h
+++ b/kopete/libkopete/kopeteglobal.h
@@ -39,13 +39,13 @@ namespace Global
* \brief Installs one or more kopete emoticon themes from a tarball
* (either .kopete-emoticons or .tar.gz or .tar.bz2)
*
- * @p localPath Full path to a local emoticon archive, use KIO to download
+ * @p localPath Full path to a local emoticon archive, use TDEIO to download
* files in case their are non-local.
*
* @return true in case install was successful, false otherwise. Errors are
- * displayed by either KIO or by using KMessagebox directly.
+ * displayed by either TDEIO or by using KMessagebox directly.
*
- * TODO: If possible, port it to KIO instead of using ugly blocking KTar
+ * TODO: If possible, port it to TDEIO instead of using ugly blocking KTar
**/
KOPETE_EXPORT void installEmoticonTheme(const TQString &localPath);
diff --git a/kopete/libkopete/kopetemetacontact.h b/kopete/libkopete/kopetemetacontact.h
index 2f918c73..15d82228 100644
--- a/kopete/libkopete/kopetemetacontact.h
+++ b/kopete/libkopete/kopetemetacontact.h
@@ -262,7 +262,7 @@ public:
void setPhotoSourceContact( Contact* contact );
/**
- * @return true if when a subcontact change his photo, the photo will be set to the kabc contact.
+ * @return true if when a subcontact change his photo, the photo will be set to the tdeabc contact.
*/
bool isPhotoSyncedWithKABC() const;
@@ -373,7 +373,7 @@ public:
* cannot be altered!
*
* @param p The Plugin by which uses this field
- * @param app refers to the application id in the libkabc database.
+ * @param app refers to the application id in the libtdeabc database.
* This should be a standardized format to make sense in the address
* book in the first place - if you could use "" as application
* then probably you should use the plugin data API instead of the
diff --git a/kopete/libkopete/kopetetransfermanager.h b/kopete/libkopete/kopetetransfermanager.h
index 0333fc5a..3df90adc 100644
--- a/kopete/libkopete/kopetetransfermanager.h
+++ b/kopete/libkopete/kopetetransfermanager.h
@@ -129,7 +129,7 @@ private:
};
/**
- * A KIO job for a kopete file transfer.
+ * A TDEIO job for a kopete file transfer.
* @author Richard Smith <kopete@metafoo.co.uk>
*/
class KOPETE_EXPORT Transfer : public TDEIO::Job
diff --git a/kopete/libkopete/kabcpersistence.cpp b/kopete/libkopete/tdeabcpersistence.cpp
index 0d03fc07..1fc46098 100644
--- a/kopete/libkopete/kabcpersistence.cpp
+++ b/kopete/libkopete/tdeabcpersistence.cpp
@@ -39,7 +39,7 @@
#include "kopetepluginmanager.h"
#include "kopeteprotocol.h"
-#include "kabcpersistence.h"
+#include "tdeabcpersistence.h"
namespace Kopete
{
@@ -218,7 +218,7 @@ void KABCPersistence::removeKABC( MetaContact *)
// This causes each Kopete::Protocol subclass to serialise its contacts' data into the metacontact's plugin data and address book data
emit aboutToSave(this);
- // If the metacontact is linked to a kabc entry
+ // If the metacontact is linked to a tdeabc entry
if ( !d->metaContactId.isEmpty() )
{
//kdDebug( 14010 ) << k_funcinfo << "looking up Addressee for " << displayName() << "..." << endl;
@@ -449,4 +449,4 @@ void KABCPersistence::dumpAB()
// dump addressbook contents
-#include "kabcpersistence.moc"
+#include "tdeabcpersistence.moc"
diff --git a/kopete/libkopete/kabcpersistence.h b/kopete/libkopete/tdeabcpersistence.h
index 3c5f4b0b..ea2b922a 100644
--- a/kopete/libkopete/kabcpersistence.h
+++ b/kopete/libkopete/tdeabcpersistence.h
@@ -25,7 +25,7 @@
// *) Add Contact Wizard
// *) KopeteMetaContact
// *) KopeteAddrBookExport
-// *) KABC Export Wizard - TODO - think about sequence of events when adding addressees AND writing their IM data. - Extra save should be unnecessary because we are sharing a kabc instance
+// *) KABC Export Wizard - TODO - think about sequence of events when adding addressees AND writing their IM data. - Extra save should be unnecessary because we are sharing a tdeabc instance
// *) Select addressbook entry
namespace TDEABC
diff --git a/kopete/libkopete/tests/kopetecontactlist_test.cpp b/kopete/libkopete/tests/kopetecontactlist_test.cpp
index 6fb0db26..71dade85 100644
--- a/kopete/libkopete/tests/kopetecontactlist_test.cpp
+++ b/kopete/libkopete/tests/kopetecontactlist_test.cpp
@@ -23,8 +23,8 @@
using namespace KUnitTest;
-KUNITTEST_MODULE( tdeunittest_kopetecontactlist_test, "KopeteSuite");
-KUNITTEST_MODULE_REGISTER_TESTER( KopeteContactList_Test );
+TDEUNITTEST_MODULE( tdeunittest_kopetecontactlist_test, "KopeteSuite");
+TDEUNITTEST_MODULE_REGISTER_TESTER( KopeteContactList_Test );
void KopeteContactList_Test::allTests()
{
diff --git a/kopete/libkopete/tests/kopeteemoticontest.cpp b/kopete/libkopete/tests/kopeteemoticontest.cpp
index f57becaa..7121ff19 100644
--- a/kopete/libkopete/tests/kopeteemoticontest.cpp
+++ b/kopete/libkopete/tests/kopeteemoticontest.cpp
@@ -34,8 +34,8 @@
using namespace KUnitTest;
-KUNITTEST_MODULE( tdeunittest_kopeteemoticontest, "KopeteSuite");
-KUNITTEST_MODULE_REGISTER_TESTER( KopeteEmoticonTest );
+TDEUNITTEST_MODULE( tdeunittest_kopeteemoticontest, "KopeteSuite");
+TDEUNITTEST_MODULE_REGISTER_TESTER( KopeteEmoticonTest );
/*
There are three sets of tests, the Kopete 0.7 baseline with tests that were
diff --git a/kopete/libkopete/tests/kopetemessage_test.cpp b/kopete/libkopete/tests/kopetemessage_test.cpp
index 43f66f88..59b24396 100644
--- a/kopete/libkopete/tests/kopetemessage_test.cpp
+++ b/kopete/libkopete/tests/kopetemessage_test.cpp
@@ -37,8 +37,8 @@
using namespace KUnitTest;
-KUNITTEST_MODULE( tdeunittest_kopetemessage_test, "KopeteSuite");
-KUNITTEST_MODULE_REGISTER_TESTER( KopeteMessage_Test );
+TDEUNITTEST_MODULE( tdeunittest_kopetemessage_test, "KopeteSuite");
+TDEUNITTEST_MODULE_REGISTER_TESTER( KopeteMessage_Test );
/*
There are four sets of tests: for each of plain text and html, we have those
diff --git a/kopete/libkopete/tests/kopetepropertiestest.cpp b/kopete/libkopete/tests/kopetepropertiestest.cpp
index 19dcff47..cec5f9ec 100644
--- a/kopete/libkopete/tests/kopetepropertiestest.cpp
+++ b/kopete/libkopete/tests/kopetepropertiestest.cpp
@@ -32,8 +32,8 @@
using namespace KUnitTest;
-KUNITTEST_MODULE( tdeunittest_kopetepropertiestest, "KopeteSuite");
-KUNITTEST_MODULE_REGISTER_TESTER( KopetePropertiesTest );
+TDEUNITTEST_MODULE( tdeunittest_kopetepropertiestest, "KopeteSuite");
+TDEUNITTEST_MODULE_REGISTER_TESTER( KopetePropertiesTest );
using namespace Kopete::Properties;
diff --git a/kopete/libkopete/tests/template_test.cpp b/kopete/libkopete/tests/template_test.cpp
index 919d25e0..8f349ac8 100644
--- a/kopete/libkopete/tests/template_test.cpp
+++ b/kopete/libkopete/tests/template_test.cpp
@@ -20,8 +20,8 @@
using namespace KUnitTest;
-KUNITTEST_MODULE( tdeunittest_template_test, "KopeteSuite");
-KUNITTEST_MODULE_REGISTER_TESTER( Template_Test );
+TDEUNITTEST_MODULE( tdeunittest_template_test, "KopeteSuite");
+TDEUNITTEST_MODULE_REGISTER_TESTER( Template_Test );
void Template_Test::allTests()
{
diff --git a/kopete/libkopete/ui/addressbookselectorwidget.cpp b/kopete/libkopete/ui/addressbookselectorwidget.cpp
index 2ff65529..3df1ea9a 100644
--- a/kopete/libkopete/ui/addressbookselectorwidget.cpp
+++ b/kopete/libkopete/ui/addressbookselectorwidget.cpp
@@ -45,7 +45,7 @@
#include "addressbookselectorwidget.h"
#include <addresseeitem.h>
-#include "kabcpersistence.h"
+#include "tdeabcpersistence.h"
using namespace Kopete::UI;
diff --git a/kopete/libkopete/ui/addresseeitem.h b/kopete/libkopete/ui/addresseeitem.h
index 786db604..b69cdeee 100644
--- a/kopete/libkopete/ui/addresseeitem.h
+++ b/kopete/libkopete/ui/addresseeitem.h
@@ -1,5 +1,5 @@
/*
- This file is part of libkabc.
+ This file is part of libtdeabc.
Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
This library is free software; you can redistribute it and/or
diff --git a/kopete/libkopete/kopetemetacontact.cpp b/kopete/libkopete/kopetemetacontact.cpp
index 65d61106..68b77535 100644
--- a/kopete/libkopete/kopetemetacontact.cpp
+++ b/kopete/libkopete/kopetemetacontact.cpp
@@ -30,7 +30,7 @@
#include <tdemessagebox.h>
#include <tdeversion.h>
-#include "kabcpersistence.h"
+#include "tdeabcpersistence.h"
#include "kopetecontactlist.h"
#include "kopetecontact.h"
#include "kopeteaccountmanager.h"
@@ -74,7 +74,7 @@ class MetaContact::Private
Contact *displayNameSourceContact;
Contact *photoSourceContact;
// used when source is kabc
TQString metaContactId;
// used when source is custom
@@ -93,7 +93,7 @@ class MetaContact::Private
TQString photoSourcePID, photoSourceAID, photoSourceCID;
// The photo cache. Reduce disk access and CPU usage.
- Picture customPicture, contactPicture, kabcPicture;
+ Picture customPicture, contactPicture, tdeabcPicture;
};
MetaContact::MetaContact()
@@ -610,8 +610,8 @@ TQString MetaContact::displayName() const
PropertySource source = displayNameSource();
if ( source == SourceKABC )
{
// kabc source, try to get from addressbook
// if the metacontact has a kabc association
if ( !metaContactId().isEmpty() )
return nameFromKABC(metaContactId());
}
@@ -652,7 +652,7 @@ TQString nameFromKABC( const TQString &id ) /*const*/
return theAddressee.formattedName();
}
}
// no kabc association, return null image
return TQString();
}
@@ -700,7 +700,7 @@ Picture &MetaContact::picture() const
{
if ( photoSource() == SourceKABC )
{
- return d->kabcPicture;
+ return d->tdeabcPicture;
}
else if ( photoSource() == SourceContact )
{
@@ -762,7 +762,7 @@ TQImage photoFromKABC( const TQString &id ) /*const*/
}
}
}
// no kabc association, return null image
return TQImage();
}
@@ -1190,7 +1190,7 @@ bool MetaContact::fromXML( const TQDomElement& element )
else
{
// lets do the best conversion for the old name tracking
- // if the custom display name is the same as kabc name, set the source to kabc
+ // if the custom display name is the same as tdeabc name, set the source to tdeabc
if ( !d->metaContactId.isEmpty() && ( d->displayName == nameFromKABC(d->metaContactId)) )
setDisplayNameSource(SourceKABC);
else
@@ -1304,7 +1304,7 @@ void MetaContact::slotUpdateAddressBookPicture()
if ( pic.data().isNull() && pic.url().isEmpty() )
pic = theAddressee.logo();
- d->kabcPicture.setPicture(pic);
+ d->tdeabcPicture.setPicture(pic);
}
}
}
@@ -1350,13 +1350,13 @@ void MetaContact::setMetaContactId( const TQString& newMetaContactId )
return;
// 1) Check the Id is not already used by another contact
// 2) cause a kabc write ( only in response to metacontactLVIProps calling this, or will
// write be called twice when creating a brand new MC? )
// 3) What about changing from one valid kabc to another, are kabc fields removed?
// 4) May be called with Null to remove an invalid kabc uid by KMC::toKABC()
// 5) Is called when reading the saved contact list
- // Don't remove IM addresses from kabc if we are changing contacts;
+ // Don't remove IM addresses from tdeabc if we are changing contacts;
// other programs may have written that data and depend on it
d->metaContactId = newMetaContactId;
KABCPersistence::self()->write( this );
@@ -1412,8 +1412,8 @@ void MetaContact::setPhotoSyncedWithKABC(bool b)
{
// Some protocols like MSN save the photo as a url in
// contact properties, we should not use this url
// to sync with kabc but try first to embed the
// photo data in the kabc addressee, because it could
// be remote resource and the local url makes no sense
TQImage fallBackImage = TQImage(newValue.toString());
if(fallBackImage.isNull())
@@ -74,7 +74,7 @@ class MetaContact::Private
Contact *displayNameSourceContact;
Contact *photoSourceContact;
- // used when source is kabc
+ // used when source is tdeabc
TQString metaContactId;
// used when source is custom
@@ -610,8 +610,8 @@ TQString MetaContact::displayName() const
if ( source == SourceKABC )
{
- // kabc source, try to get from addressbook
- // if the metacontact has a kabc association
+ // tdeabc source, try to get from addressbook
+ // if the metacontact has a tdeabc association
if ( !metaContactId().isEmpty() )
return nameFromKABC(metaContactId());
@@ -652,7 +652,7 @@ TQString nameFromKABC( const TQString &id ) /*const*/
}
}
- // no kabc association, return null image
+ // no tdeabc association, return null image
return TQString();
}
@@ -762,7 +762,7 @@ TQImage photoFromKABC( const TQString &id ) /*const*/
}
}
- // no kabc association, return null image
+ // no tdeabc association, return null image
return TQImage();
}
@@ -1350,13 +1350,13 @@ void MetaContact::setMetaContactId( const TQString& newMetaContactId )
return;
// 1) Check the Id is not already used by another contact
- // 2) cause a kabc write ( only in response to metacontactLVIProps calling this, or will
+ // 2) cause a tdeabc write ( only in response to metacontactLVIProps calling this, or will
// write be called twice when creating a brand new MC? )
@@ -1350,13 +1350,13 @@ void MetaContact::setMetaContactId( const TQString& newMetaContactId )
// write be called twice when creating a brand new MC? )
- // 3) What about changing from one valid kabc to another, are kabc fields removed?
- // 4) May be called with Null to remove an invalid kabc uid by KMC::toKABC()
+ // 3) What about changing from one valid tdeabc to another, are tdeabc fields removed?
+ // 4) May be called with Null to remove an invalid tdeabc uid by KMC::toKABC()
// 5) Is called when reading the saved contact list
@@ -1412,8 +1412,8 @@ void MetaContact::setPhotoSyncedWithKABC(bool b)
// Some protocols like MSN save the photo as a url in
// contact properties, we should not use this url
- // to sync with kabc but try first to embed the
- // photo data in the kabc addressee, because it could
+ // to sync with tdeabc but try first to embed the
+ // photo data in the tdeabc addressee, because it could
// be remote resource and the local url makes no sense
TQImage fallBackImage = TQImage(newValue.toString());
diff --git a/kopete/libkopete/kopeteprotocol.cpp b/kopete/libkopete/kopeteprotocol.cpp
index b0758128..6a2d3279 100644
--- a/kopete/libkopete/kopeteprotocol.cpp
+++ b/kopete/libkopete/kopeteprotocol.cpp
@@ -194,7 +194,7 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
// The Unicode chars E000-F800 are non-printable and reserved for
// private use in applications. For more details, see also
// http://www.unicode.org/charts/PDF/UE000.pdf.
- // Inside libkabc the use of TQChar( 0xE000 ) has been standardized
+ // Inside libtdeabc the use of TQChar( 0xE000 ) has been standardized
// as separator for the string lists, use this also for the 'normal'
// serialized data.
if( serializedData.contains( it.key() ) )
@@ -222,9 +222,9 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
// FIXME: This is a terrible hack to check the key name for the phrase "messaging/"
// to indicate what app name to use, but for now it's by far the easiest
// way to get this working.
- // Once all this is in CVS and the actual storage in libkabc is working
+ // Once all this is in CVS and the actual storage in libtdeabc is working
// we can devise a better API, but with the constantly changing
// requirements every time I learn more about kabc I'd better no touch
// the API yet - Martijn
if( it.key().startsWith( TQString::fromLatin1( "messaging/" ) ) )
{
@@ -283,12 +283,12 @@ void Protocol::deserialize( MetaContact *metaContact, const TQMap<TQString, TQSt
// book data in the deserializer yet, only when serializing.
// - Martijn
TQMap<TQString, TQString> ad;
- TQStringList kabcFields = addressBookFields();
- for( TQStringList::Iterator fieldIt = kabcFields.begin(); fieldIt != kabcFields.end(); ++fieldIt )
+ TQStringList tdeabcFields = addressBookFields();
+ for( TQStringList::Iterator fieldIt = tdeabcFields.begin(); fieldIt != tdeabcFields.end(); ++fieldIt )
{
// FIXME: This hack is even more ugly, and has the same reasons as the similar
// hack in the serialize code.
// Once this code is actually capable of talking to kabc this hack
// should be removed ASAP! - Martijn
if( ( *fieldIt ).startsWith( TQString::fromLatin1( "messaging/" ) ) )
ad[ *fieldIt ] = metaContact->addressBookField( this, *fieldIt, TQString::fromLatin1( "All" ) );
@@ -222,9 +222,9 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
// we can devise a better API, but with the constantly changing
- // requirements every time I learn more about kabc I'd better no touch
+ // requirements every time I learn more about tdeabc I'd better no touch
// the API yet - Martijn
if( it.key().startsWith( TQString::fromLatin1( "messaging/" ) ) )
@@ -283,12 +283,12 @@ void Protocol::deserialize( MetaContact *metaContact, const TQMap<TQString, TQSt
// FIXME: This hack is even more ugly, and has the same reasons as the similar
// hack in the serialize code.
- // Once this code is actually capable of talking to kabc this hack
+ // Once this code is actually capable of talking to tdeabc this hack
// should be removed ASAP! - Martijn
if( ( *fieldIt ).startsWith( TQString::fromLatin1( "messaging/" ) ) )